################################################################################
make clean
make distclean

rm -f compile
rm -r -f autom4te.cache
rm -r -f m4
rm -f aclocal.m4
rm -f config.h.in
rm -f config.sub
rm -f config.guess
rm -f configure
rm -f depcomp
rm -f INSTALL
rm -f install-sh
rm -f ltmain.sh
rm -f Makefile.in
rm -f missing
rm -f deb/Makefile.in
rm -f deb/control
rm -f src/Makefile.in
rm -f src/biblioteca/Makefile.in
rm -f src/headers/Makefile.in
rm -f doc/Makefile.in
rm -f manual/Makefile.in
rm -f manual/imagenes/Makefile.in


rm -f config.h
rm -f config.log
rm -f config.status
rm -f stamp-h1
rm -f Makefile

rm -f *.c.tags

################################################################################

